---
description: Interview me about the plan
argument-hint: [plan]
model: opus
---

Read this plan file $1 and interview me in detail using the AskUserQuestionTool about
literally anything: technical implementation, UI & UX, concerns, tradeoffs, etc.
but make sure the questions are not obvious.

Be very in-depth and continue interviewing me continually until it’s complete, then write the spec to the file.